<?php
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

include('includes/header.php');

// Function to decode JSON content safely
function decodeJSON($jsonString)
{
    $data = json_decode($jsonString, true);
    if (json_last_error() !== JSON_ERROR_NONE) {
        throw new Exception("Error decoding JSON content: " . json_last_error_msg());
    }
    return $data;
}

// Read server.json content
$jsonFilePath = './api/server.json';
$jsonData = file_get_contents($jsonFilePath);

try {
    $data = decodeJSON($jsonData);
} catch (Exception $e) {
    echo "Error decoding JSON content: " . $e->getMessage();
    exit;
}

// Add a new server
if (isset($_POST['add_server'])) {
    $newServer = array(
        "country" => $_POST['country'],
        "city" => $_POST['city'],
        "file" => $_POST['file']
    );

    $data['files'][] = $newServer;

    // Save the updated configuration to server.json
    $newJsonData = json_encode($data, JSON_PRETTY_PRINT);
    file_put_contents($jsonFilePath, $newJsonData);
}

// Delete a server
if (isset($_POST['delete_server'])) {
    $serverId = (int)$_POST['delete_server'];

    // Remove the server with the specified id
    unset($data['files'][$serverId - 1]);

    // Reindex the array
    $data['files'] = array_values($data['files']);

    // Save the updated configuration to server.json
    $newJsonData = json_encode($data, JSON_PRETTY_PRINT);
    file_put_contents($jsonFilePath, $newJsonData);
}
?>

<!-- Your HTML code here -->

<style>
    /* Your existing styles */

    h3 {
        color: #4e73df;
        margin-bottom: 20px; /* Adjust the margin as needed */
    }
</style>

<h3 class="m-0 font-weight-bold text-primary text-center"><i class="fas fa-server"></i> VPN Servers </h3>
<br> <!-- Added line break for spacing -->

<style>
    form {        
        margin-bottom: 1px;
        margin-top: 1px;
    }

    button {
        background-color: #4e73df;
        color: #ffffff;
        border: none;
        padding: 10px 15px;
        cursor: pointer;
        border-radius: 5px;
    }

    table {
        width: 100%;
        border-collapse: collapse;
        margin-top: 4px;
    }

    th, td {
        padding: 15px;
        text-align: left;
        border-bottom: 1px solid #dddddd;
    }

    th {
        background-color: #4e73df;
        color: #ffffff;
    }

    tr:hover {
        background-color: #f5f5f5;
    }

    form button:hover {
        background-color: #2e59d9;
    }

    form button, td button {
        transition: background-color 0.3s;
    }

    td button {
        background-color: #e74a3b;
        color: #ffffff;
        border: none;
        padding: 8px 12px;
        cursor: pointer;
        border-radius: 3px;
    }

    td button:hover {
        background-color: #c23b2b;
    }
</style>

<form method="post">
    <input type="text" name="country" placeholder="Country" required>
    <input type="text" name="city" placeholder="City" required>
    <input type="text" name="file" placeholder="File" required>
    <button type="submit" name="add_server">Add Server</button>
</form>

<table>
    <thead>
        <tr>
            <th>Server</th>
            <th>Country</th>
            <th>City</th>
            <th>File</th>
            <th>Delete</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($data['files'] as $i => $server) : ?>
            <tr>
                <td><?php echo $i + 1; ?></td>
                <td><?php echo $server['country']; ?></td>
                <td><?php echo $server['city']; ?></td>
                <td><?php echo $server['file']; ?></td>
                <td>
                    <form method="post">
                        <input type="hidden" name="delete_server" value="<?php echo $i + 1; ?>">
                        <button type="submit">Delete</button>
                    </form>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>

<!-- Your HTML code here -->

<?php include('includes/footer.php'); ?>
